@@ -23,13 +23,13 @@
 #define __GST_MISTELIX_SOCKET_H__
 
 int
-gst_mistelix_video_src_deamon_init ();
+gst_mistelix_video_src_daemon_init ();
 
 int
-gst_mistelix_video_src_deamon_getfile (unsigned char** buffer, int* length, int* fixed);
+gst_mistelix_video_src_daemon_getfile (unsigned char** buffer, int* length, int* fixed);
 
 void
-gst_mistelix_video_src_deamon_shutdown ();
+gst_mistelix_video_src_daemon_shutdown ();
 
 
 #endif
