@@ -1,5 +1,5 @@
 //
-// Copyright (C) 2008-2009 Jordi Mas i Hernandez, jmas@softcatala.org
+// Copyright (C) 2008-2010 Jordi Mas i Hernandez, jmas@softcatala.org
 //
 // Permission is hereby granted, free of charge, to any person obtaining
 // a copy of this software and associated documentation files (the
@@ -46,25 +46,25 @@ namespace Mistelix
 	//
 	class Mistelix : Program
 	{
-		[Glade.Widget ("mistelix")] Gtk.Window app_window;
-		[Glade.Widget ("vertical_paned")] Gtk.HPaned vpaned;
-		[Glade.Widget ("vpaned_horizontal")] Gtk.VPaned hpaned;
-		[Glade.Widget ("scrolledwindow_elements")] Gtk.ScrolledWindow scrolledwin_elements;
-		[Glade.Widget] Gtk.VBox left_vbox;
-
-		[Glade.Widget] Gtk.MenuItem save_project;
-		[Glade.Widget] Gtk.MenuItem save_as;
-		[Glade.Widget] Gtk.MenuItem build;
-		[Glade.Widget] Gtk.MenuItem theme_browser;
-		[Glade.Widget] Gtk.MenuItem project_properties;
-		[Glade.Widget] Gtk.Button videos_button;
-		[Glade.Widget] Gtk.Button slideshows_button;
-		[Glade.Widget] Gtk.CheckMenuItem safearea_menuitem;
-		[Glade.Widget] Gtk.MenuItem add_slideshow;
-		[Glade.Widget] Gtk.MenuItem add_videos;
-		[Glade.Widget] Gtk.VBox rightpaned_vbox;
-		[Glade.Widget] Gtk.VBox buttons_vbox;
-		[Glade.Widget] Gtk.MenuItem recent_menuitem;
+		[GtkBeans.Builder.Object ("mistelix")] Gtk.Window app_window;
+		[GtkBeans.Builder.Object ("vertical_paned")] Gtk.HPaned vpaned;
+		[GtkBeans.Builder.Object ("vpaned_horizontal")] Gtk.VPaned hpaned;
+		[GtkBeans.Builder.Object ("scrolledwindow_elements")] Gtk.ScrolledWindow scrolledwin_elements;
+		[GtkBeans.Builder.Object] Gtk.VBox left_vbox;
+		[GtkBeans.Builder.Object] Gtk.MenuItem save_menuitem;
+		[GtkBeans.Builder.Object] Gtk.MenuItem saveas_menuitem;
+		[GtkBeans.Builder.Object] Gtk.MenuItem build_menuitem;
+		[GtkBeans.Builder.Object] Gtk.MenuItem theme_menuitem;
+		[GtkBeans.Builder.Object] Gtk.MenuItem properties_menuitem;
+		[GtkBeans.Builder.Object] Gtk.MenuItem close_menuitem;
+		[GtkBeans.Builder.Object] Gtk.Button videos_button;
+		[GtkBeans.Builder.Object] Gtk.Button slideshows_button;
+		[GtkBeans.Builder.Object] Gtk.CheckMenuItem safearea_menuitem;
+		[GtkBeans.Builder.Object] Gtk.MenuItem add_slideshow;
+		[GtkBeans.Builder.Object] Gtk.MenuItem add_videos;
+		[GtkBeans.Builder.Object] Gtk.VBox rightpaned_vbox;
+		[GtkBeans.Builder.Object] Gtk.VBox buttons_vbox;
+		[GtkBeans.Builder.Object] Gtk.MenuItem recent_menuitem;
 		ExtendedMenu recent_submenu;
 
 		AuthoringPaneView authoring_view;
@@ -78,6 +78,8 @@ namespace Mistelix
 
 		static Mistelix ()
 		{
+			string debug;
+
 			base_dir = System.IO.Path.Combine (Environment.GetFolderPath (Environment.SpecialFolder.ApplicationData), Defines.APPNAME_LOWER);
 
 			// Mono addins
@@ -88,7 +90,9 @@ namespace Mistelix
 			preferences = new Preferences ();
 			recent_files = new RecentFilesStorage ();
 
-			if (String.Compare (Environment.GetEnvironmentVariable ("MISTELIX_DEBUG"), "true", false) == 0) { 
+			debug = Environment.GetEnvironmentVariable ("MISTELIX_DEBUG");
+
+			if (String.Compare (debug, "true", false) == 0 || String.Compare (debug, "1", false) == 0) { 
 				debugging = true;
 				Logger.LogLevel = Level.DEBUG;
 				Logger.LogDevice = new FileLogger ();
@@ -103,8 +107,8 @@ namespace Mistelix
 
 			Catalog.Init ("mistelix", Defines.GNOME_LOCALE_DIR);
 
-			Glade.XML gXML = new Glade.XML (null, "mistelix.glade", "mistelix", null);
-			gXML.Autoconnect (this);
+			GtkBeans.Builder builder = new GtkBeans.Builder ("mistelix.ui");
+			builder.Autoconnect (this);
 
 			foreach (TypeExtensionNode node in AddinManager.GetExtensionNodes ("/Mistelix/SlideTransitions"))
 				Logger.Info ("Extension:" + node.CreateInstance ());
@@ -148,14 +152,14 @@ namespace Mistelix
 		void SensitiveToProjectContext ()
 		{
 			bool active = (project == null ? false : true);
-
-			save_project.Sensitive = active;
-			save_as.Sensitive = active;
-			build.Sensitive = active;
+			save_menuitem.Sensitive = active;
+			saveas_menuitem.Sensitive = active;
+			build_menuitem.Sensitive = active;
+			close_menuitem.Sensitive = active;
 			slideshows_button.Sensitive = active;
-			project_properties.Sensitive = active;
+			properties_menuitem.Sensitive = active;
 			add_slideshow.Sensitive = active;
-	
+
 			if (project == null) { // WelcomeView
 				rightpaned_vbox.Remove (scrolledwin_elements);
 				left_vbox.HideAll ();
@@ -178,7 +182,7 @@ namespace Mistelix
 			}
 
 			add_videos.Sensitive = active;
-			theme_browser.Sensitive = active;
+			theme_menuitem.Sensitive = active;
 			safearea_menuitem.Sensitive = active;
 			videos_button.Sensitive = active;
 		}
@@ -213,7 +217,7 @@ namespace Mistelix
 		{
 			AddVideoDialog dialog = new AddVideoDialog ();
 
-			if (dialog.Run () == ResponseType.Ok) {
+			if (dialog.RunModal () == ResponseType.Ok) {
 				foreach (VideoProjectElement video in dialog.Videos) {
 					project.AddElement (video);
 					element_view.AddElement (video);
@@ -240,7 +244,7 @@ namespace Mistelix
 		void OnPreferences (object sender, EventArgs args)
 		{
 			PreferencesDialog dialog = new PreferencesDialog ();
-			if (dialog.Run () != ResponseType.Ok)
+			if (dialog.RunModal () != ResponseType.Ok)
 				return;
 
 			if (dialog.NeedsRepaint) {
@@ -322,8 +326,26 @@ namespace Mistelix
 		{
 			Dependencies dependencies;
 			bool support;
+			string msg_audio;
 
 			dependencies = new Dependencies ();
+
+			if (project.AudioSupportedFormat (out msg_audio) == false)
+			{
+				string msg;
+				
+				msg = String.Format (Catalog.GetString (
+					// Translators: {0} is the error message
+					"{0}\n\nGo to 'Check Mistelix's Dependencies Requirements' dialog and make sure that you have the right audio codecs installed.\n\nIf you continue, your project will have no audio."), 
+					msg_audio);
+
+				MessageDialog md = new MessageDialog (app_window,
+		                      	DialogFlags.Modal, MessageType.Warning,
+		                      	ButtonsType.Ok, false, msg);
+
+				md.Run ();
+				md.Destroy ();
+			}
 						
 			if (project.Details.Type == ProjectType.DVD)
 				support = dependencies.DvdSupport;
@@ -333,7 +355,7 @@ namespace Mistelix
 			if (support == false) {
 				CheckDependenciesDialog dependencies_dialog = new CheckDependenciesDialog (project);
 				dependencies_dialog.Dependencies = dependencies;
-				dependencies_dialog.Run ();
+				dependencies_dialog.RunModal ();
 				return;
 			}
 
@@ -366,7 +388,7 @@ namespace Mistelix
 			}
 
 			BuildProjectDialog build_dialog = new BuildProjectDialog (project);
-			build_dialog.Run ();
+			build_dialog.RunModal ();
 		}
 
 		void OnNewProject (object sender, EventArgs args)
@@ -377,7 +399,7 @@ namespace Mistelix
 		void NewProject (ProjectType type)
 		{	
 			NewProjectDialog dialog = new NewProjectDialog (type);
-			if (dialog.Run () == ResponseType.Ok) {
+			if (dialog.RunModal () == ResponseType.Ok) {
 				project = authoring_view.Project = element_view.Project = dialog.NewProject;
 				SensitiveToProjectContext ();
 				element_view.LoadElements ();
@@ -399,7 +421,7 @@ namespace Mistelix
 		void OnThemeBrowser (object sender, EventArgs args)
 		{
 			ThemeSelectionDialog dialog = new ThemeSelectionDialog (project);
-			if (dialog.Run () == ResponseType.Ok) {
+			if (dialog.RunModal () == ResponseType.Ok) {
 				authoring_view.UpdateTheme ();
 			}
 		}
@@ -546,7 +568,7 @@ namespace Mistelix
 		{
 			ProjectPropertiesDialog dialog = new ProjectPropertiesDialog (project);
 
-			if (dialog.Run () != ResponseType.Ok)
+			if (dialog.RunModal () != ResponseType.Ok)
 				return;
 
 			// Properties dlg can change default font, colours and menu thumbnails
@@ -565,7 +587,7 @@ namespace Mistelix
 		void OnCheckDependencies (object sender, EventArgs args)
 		{
 			CheckDependenciesDialog dialog = new CheckDependenciesDialog (project);
-			dialog.Run ();
+			dialog.RunModal ();
 		}
 
 		void UpdateWindowTitle ()
